แพ็คเกจPythonที่แสดงข้อมูลเกี่ยวกับPeterJuice
=============================================

PyPi: https://pypi.org/project/peterjuice/

สวัสดีครับ แพ็คเกจนี้คือแพ็คเกจที่แสดงข้อมูลเกี่ยวกับตัวของผมนะครับ
ท่านสามารถที่จะดูลิงค์ยูทูปและ ภาพasciiได้ครับ

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install peterjuice 

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from peterjuice import PeterJuice

   Peter = PeterJuice() #ประกาศชื่อclass
   Peter.show_name() #แสดงรายละเอียดชื่อ
   Peter.show_YT() #แสดงลิงค์Youtube
   Peter.aboutme() #เกี่ยวกับตัวผม
   Peter.show_art() #แสดงภาพArt

พัฒนาโดย: Peterjuice YouTube: https://www.youtube.com/@redcometz6205
